from distutils.core import setup

setup(
  name = 'bnlp3',
  packages = ['bnlp3'],
  package_dir = {'bnlp3': 'bnlp3'},
  package_data = {'bnlp3': ['*']},
  version = '0.7',
  description = 'Better Natural Language Processing, a collection of open source nlp methods used by Better Know The Opposition',
  author = 'Better Know The Opposition',
  author_email = 'hello@betterknowtheopposition.com',
  url = 'https://github.com/BKTO/bnlp3',
  download_url = 'https://github.com/BKTO/bnlp3',
  keywords = ['nlp'],
  classifiers = [],
)
